@@ -84,9 +84,13 @@ def main(args = sys.argv[1:]):
         with open(parsed_args.parameters) as parameters_json:
             parameters = json.load(parameters_json)
 
+    appendix = parsed_args.output_name_appendix
+    if appendix != "": 
+        appendix = "-" + appendix
+
     for sample_name in sample_names:
         results_representations = {}
-        for model_path, model_desc_info in models.items():
+        for model_path, model_desc in models.items():
             if ".yml" in model_path:
                 data_accessor = DataAccessor(
                     genotypes = vcf_accessor,
@@ -96,19 +100,11 @@ def main(args = sys.argv[1:]):
                     af_field_name = "AF_nfe",
                     parameters = parameters)
                 model = SeqqlOperator.fromYaml(model_path)
-                #model.compute(data_accessor)
-                print()
                 model.compute(data_accessor)
-                print(json.dumps(model.refine_results(), indent=2))
-#            else:
-#                res = process_model(model_desc_info, vcf_accessor, allele_accessor, population, sample_name)
-#                results_representations[model_path] = create_res_representation_for_model(res, model_desc_info, parsed_args.population)
-        appendix = parsed_args.output_name_appendix
-        if appendix != "": 
-            appendix = "-" + appendix
+            with open(os.path.join(out_dir, f'{sample_name}-{model_desc["name"]}{appendix}.sample.json'), 'w') as f:
+                json.dump(model.refine_results(), f, indent=2)
+                #json.dump(results_representations, f, indent=4)
 
-        with open(os.path.join(out_dir, f'{sample_name}{appendix}.sample.json'), 'w') as f:
-            json.dump(results_representations, f, indent=4)
 
 
 if __name__ == '__main__':
