@@ -379,7 +379,7 @@ def biobankuk_index(args):
         description='polygenicmaker biobankuk-index downloads index of gwas results from pan.ukbb study')  # todo dodać opis
     parser.add_argument('--url', type=str, default='https://pan-ukb-us-east-1.s3.amazonaws.com/sumstats_release/phenotype_manifest.tsv.bgz',
                         help='alternative url location for index')
-    pasrer.add_argument('--variant-metrics', type=str, default='https://pan-ukb-us-east-1.s3.amazonaws.com/sumstats_release/full_variant_qc_metrics.txt.bgz',
+    parser.add_argument('--variant-metrics', type=str, default='https://pan-ukb-us-east-1.s3.amazonaws.com/sumstats_release/full_variant_qc_metrics.txt.bgz',
                         help='alternative url location for variant metrics')
     parser.add_argument('--output-directory', type=str, default='',
                         help='output directory')
@@ -467,8 +467,8 @@ def biobankuk_model(args):
     source_vcf = VcfAccessor(parsed_args.source_ref_vcf)
     target_vcf = VcfAccessor(parsed_args.target_ref_vcf)
 
-    #filter_pval(path, parsed_args)
-    #clump(path, parsed_args)
+    filter_pval(path, parsed_args)
+    clump(path, parsed_args)
 
     data = read_table(path + ".clumped")
     for line in data: line.update({"rsid": line['chr'] + ":" + line['pos'] + "_" + line['ref'] + "_" + line['alt']})
